From e2e76294f592c3195d06ec69c552f5600efd94c3 Mon Sep 17 00:00:00 2001
From: Jelte Fennema-Nio <jelte.fennema@microsoft.com>
Date: Wed, 14 Feb 2024 17:19:42 +0100
Subject: [PATCH v3 3/5] Bring editorconfig in line with gitattributes

Our .gitattributes file is configured to complain about several
whitespace issues. This updates our .editorconfig file to make many
editors and IDEs fix these issues automatically on save in the same way.
---
 .editorconfig | 66 +++++++++++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 66 insertions(+)

diff --git a/.editorconfig b/.editorconfig
index d69a3d1dc4e..fad3fb5901f 100644
--- a/.editorconfig
+++ b/.editorconfig
@@ -1,10 +1,19 @@
 root = true
 
+[*]
+trim_trailing_whitespace = true
+insert_final_newline = true
+
 [*.{c,h,l,y,pl,pm}]
 indent_style = tab
 indent_size = tab
 tab_width = 4
 
+[*.po]
+# This does not provide indent_size since .po files don't have indentation.
+# Setting indent_style is only done to prevent accidental insertion of tabs.
+indent_style = space
+
 [*.{sgml,xml}]
 indent_style = space
 indent_size = 1
@@ -12,3 +21,60 @@ indent_size = 1
 [*.xsl]
 indent_style = space
 indent_size = 2
+
+# Certain data files that contain special whitespace, and other special cases
+[*.data]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[contrib/pgcrypto/sql/pgp-armor.sql]
+trim_trailing_whitespace = false
+
+[src/backend/catalog/sql_features.txt]
+trim_trailing_whitespace = false
+
+# Test output files that contain extra whitespace
+[*.out]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/interfaces/ecpg/test/expected/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+# These files are maintained or generated elsewhere.  We take them as is.
+[configure]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[ppport.h]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/regex/COPYRIGHT]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/snowball/libstemmer/*.c]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/backend/utils/mb/Unicode/*-std.txt]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/include/snowball/libstemmer/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/timezone/data/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/tools/pg_bsd_indent/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
+
+[src/tools/pg_bsd_indent/tests/*]
+trim_trailing_whitespace = false
+insert_final_newline = unset
-- 
2.34.1

